import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_common_unimodel_details import (
        GithubComKalshiExchangeInfraCommonUnimodelDetails,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelMilestone")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelMilestone:
    """
    Attributes:
        category (Union[Unset, str]): Category of the milestone.
        details (Union[Unset, GithubComKalshiExchangeInfraCommonUnimodelDetails]):
        end_date (Union[Unset, datetime.datetime]): End date of the milestone, if any.
        id (Union[Unset, str]): Unique identifier for the milestone.
        last_updated_ts (Union[Unset, datetime.datetime]): Last time this structured target was updated.
        notification_message (Union[Unset, str]): Notification message for the milestone.
        primary_event_tickers (Union[Unset, list[str]]): List of event tickers directly related to the outcome of this
            milestone.
        related_event_tickers (Union[Unset, list[str]]): List of event tickers related to this milestone.
        source_id (Union[Unset, str]): Source id of milestone if available.
        start_date (Union[Unset, datetime.datetime]): Start date of the milestone.
        title (Union[Unset, str]): Title of the milestone.
        type_ (Union[Unset, str]): Type of the milestone.
    """

    category: Union[Unset, str] = UNSET
    details: Union[Unset, "GithubComKalshiExchangeInfraCommonUnimodelDetails"] = UNSET
    end_date: Union[Unset, datetime.datetime] = UNSET
    id: Union[Unset, str] = UNSET
    last_updated_ts: Union[Unset, datetime.datetime] = UNSET
    notification_message: Union[Unset, str] = UNSET
    primary_event_tickers: Union[Unset, list[str]] = UNSET
    related_event_tickers: Union[Unset, list[str]] = UNSET
    source_id: Union[Unset, str] = UNSET
    start_date: Union[Unset, datetime.datetime] = UNSET
    title: Union[Unset, str] = UNSET
    type_: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        category = self.category

        details: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict()

        end_date: Union[Unset, str] = UNSET
        if not isinstance(self.end_date, Unset):
            end_date = self.end_date.isoformat()

        id = self.id

        last_updated_ts: Union[Unset, str] = UNSET
        if not isinstance(self.last_updated_ts, Unset):
            last_updated_ts = self.last_updated_ts.isoformat()

        notification_message = self.notification_message

        primary_event_tickers: Union[Unset, list[str]] = UNSET
        if not isinstance(self.primary_event_tickers, Unset):
            primary_event_tickers = self.primary_event_tickers

        related_event_tickers: Union[Unset, list[str]] = UNSET
        if not isinstance(self.related_event_tickers, Unset):
            related_event_tickers = self.related_event_tickers

        source_id = self.source_id

        start_date: Union[Unset, str] = UNSET
        if not isinstance(self.start_date, Unset):
            start_date = self.start_date.isoformat()

        title = self.title

        type_ = self.type_

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if category is not UNSET:
            field_dict["category"] = category
        if details is not UNSET:
            field_dict["details"] = details
        if end_date is not UNSET:
            field_dict["end_date"] = end_date
        if id is not UNSET:
            field_dict["id"] = id
        if last_updated_ts is not UNSET:
            field_dict["last_updated_ts"] = last_updated_ts
        if notification_message is not UNSET:
            field_dict["notification_message"] = notification_message
        if primary_event_tickers is not UNSET:
            field_dict["primary_event_tickers"] = primary_event_tickers
        if related_event_tickers is not UNSET:
            field_dict["related_event_tickers"] = related_event_tickers
        if source_id is not UNSET:
            field_dict["source_id"] = source_id
        if start_date is not UNSET:
            field_dict["start_date"] = start_date
        if title is not UNSET:
            field_dict["title"] = title
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_common_unimodel_details import (
            GithubComKalshiExchangeInfraCommonUnimodelDetails,
        )

        d = dict(src_dict)
        category = d.pop("category", UNSET)

        _details = d.pop("details", UNSET)
        details: Union[Unset, GithubComKalshiExchangeInfraCommonUnimodelDetails]
        if isinstance(_details, Unset):
            details = UNSET
        else:
            details = GithubComKalshiExchangeInfraCommonUnimodelDetails.from_dict(_details)

        _end_date = d.pop("end_date", UNSET)
        end_date: Union[Unset, datetime.datetime]
        if isinstance(_end_date, Unset):
            end_date = UNSET
        else:
            end_date = isoparse(_end_date)

        id = d.pop("id", UNSET)

        _last_updated_ts = d.pop("last_updated_ts", UNSET)
        last_updated_ts: Union[Unset, datetime.datetime]
        if isinstance(_last_updated_ts, Unset):
            last_updated_ts = UNSET
        else:
            last_updated_ts = isoparse(_last_updated_ts)

        notification_message = d.pop("notification_message", UNSET)

        primary_event_tickers = cast(list[str], d.pop("primary_event_tickers", UNSET))

        related_event_tickers = cast(list[str], d.pop("related_event_tickers", UNSET))

        source_id = d.pop("source_id", UNSET)

        _start_date = d.pop("start_date", UNSET)
        start_date: Union[Unset, datetime.datetime]
        if isinstance(_start_date, Unset):
            start_date = UNSET
        else:
            start_date = isoparse(_start_date)

        title = d.pop("title", UNSET)

        type_ = d.pop("type", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_milestone = cls(
            category=category,
            details=details,
            end_date=end_date,
            id=id,
            last_updated_ts=last_updated_ts,
            notification_message=notification_message,
            primary_event_tickers=primary_event_tickers,
            related_event_tickers=related_event_tickers,
            source_id=source_id,
            start_date=start_date,
            title=title,
            type_=type_,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_milestone.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_milestone

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_get_markets_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
    series_ticker: Union[Unset, str] = UNSET,
    max_close_ts: Union[Unset, int] = UNSET,
    min_close_ts: Union[Unset, int] = UNSET,
    status: Union[Unset, str] = UNSET,
    tickers: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["limit"] = limit

    params["cursor"] = cursor

    params["event_ticker"] = event_ticker

    params["series_ticker"] = series_ticker

    params["max_close_ts"] = max_close_ts

    params["min_close_ts"] = min_close_ts

    params["status"] = status

    params["tickers"] = tickers

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/markets",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
    series_ticker: Union[Unset, str] = UNSET,
    max_close_ts: Union[Unset, int] = UNSET,
    min_close_ts: Union[Unset, int] = UNSET,
    status: Union[Unset, str] = UNSET,
    tickers: Union[Unset, str] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]:
    r"""Get Markets

      Endpoint for listing and discovering markets on Kalshi. A market represents a specific binary
    outcome within an event that users can trade on (e.g., \"Will candidate X win?\"). Markets have
    yes/no positions, current prices, volume, and settlement rules. This endpoint returns a paginated
    response. Use the 'limit' parameter to control page size (1-1000, defaults to 100). The response
    includes a 'cursor' field - pass this value in the 'cursor' parameter of your next request to get
    the next page. An empty cursor indicates no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        event_ticker (Union[Unset, str]): Filter markets by event ticker. Returns only markets
            belonging to the specified event.
        series_ticker (Union[Unset, str]): Filter markets by series ticker. Returns only markets
            belonging to events in the specified series.
        max_close_ts (Union[Unset, int]): Filter markets that close before this Unix timestamp.
        min_close_ts (Union[Unset, int]): Filter markets that close after this Unix timestamp.
        status (Union[Unset, str]): Filter by market status. Comma-separated list. Possible
            values: 'unopened', 'open', 'closed', 'settled'. Leave empty to return markets with any
            status.
        tickers (Union[Unset, str]): Filter by specific market tickers. Comma-separated list of
            market tickers to retrieve.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]
    """

    kwargs = _get_kwargs(
        limit=limit,
        cursor=cursor,
        event_ticker=event_ticker,
        series_ticker=series_ticker,
        max_close_ts=max_close_ts,
        min_close_ts=min_close_ts,
        status=status,
        tickers=tickers,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
    series_ticker: Union[Unset, str] = UNSET,
    max_close_ts: Union[Unset, int] = UNSET,
    min_close_ts: Union[Unset, int] = UNSET,
    status: Union[Unset, str] = UNSET,
    tickers: Union[Unset, str] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]:
    r"""Get Markets

      Endpoint for listing and discovering markets on Kalshi. A market represents a specific binary
    outcome within an event that users can trade on (e.g., \"Will candidate X win?\"). Markets have
    yes/no positions, current prices, volume, and settlement rules. This endpoint returns a paginated
    response. Use the 'limit' parameter to control page size (1-1000, defaults to 100). The response
    includes a 'cursor' field - pass this value in the 'cursor' parameter of your next request to get
    the next page. An empty cursor indicates no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        event_ticker (Union[Unset, str]): Filter markets by event ticker. Returns only markets
            belonging to the specified event.
        series_ticker (Union[Unset, str]): Filter markets by series ticker. Returns only markets
            belonging to events in the specified series.
        max_close_ts (Union[Unset, int]): Filter markets that close before this Unix timestamp.
        min_close_ts (Union[Unset, int]): Filter markets that close after this Unix timestamp.
        status (Union[Unset, str]): Filter by market status. Comma-separated list. Possible
            values: 'unopened', 'open', 'closed', 'settled'. Leave empty to return markets with any
            status.
        tickers (Union[Unset, str]): Filter by specific market tickers. Comma-separated list of
            market tickers to retrieve.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse
    """

    return sync_detailed(
        client=client,
        limit=limit,
        cursor=cursor,
        event_ticker=event_ticker,
        series_ticker=series_ticker,
        max_close_ts=max_close_ts,
        min_close_ts=min_close_ts,
        status=status,
        tickers=tickers,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
    series_ticker: Union[Unset, str] = UNSET,
    max_close_ts: Union[Unset, int] = UNSET,
    min_close_ts: Union[Unset, int] = UNSET,
    status: Union[Unset, str] = UNSET,
    tickers: Union[Unset, str] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]:
    r"""Get Markets

      Endpoint for listing and discovering markets on Kalshi. A market represents a specific binary
    outcome within an event that users can trade on (e.g., \"Will candidate X win?\"). Markets have
    yes/no positions, current prices, volume, and settlement rules. This endpoint returns a paginated
    response. Use the 'limit' parameter to control page size (1-1000, defaults to 100). The response
    includes a 'cursor' field - pass this value in the 'cursor' parameter of your next request to get
    the next page. An empty cursor indicates no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        event_ticker (Union[Unset, str]): Filter markets by event ticker. Returns only markets
            belonging to the specified event.
        series_ticker (Union[Unset, str]): Filter markets by series ticker. Returns only markets
            belonging to events in the specified series.
        max_close_ts (Union[Unset, int]): Filter markets that close before this Unix timestamp.
        min_close_ts (Union[Unset, int]): Filter markets that close after this Unix timestamp.
        status (Union[Unset, str]): Filter by market status. Comma-separated list. Possible
            values: 'unopened', 'open', 'closed', 'settled'. Leave empty to return markets with any
            status.
        tickers (Union[Unset, str]): Filter by specific market tickers. Comma-separated list of
            market tickers to retrieve.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]
    """

    kwargs = _get_kwargs(
        limit=limit,
        cursor=cursor,
        event_ticker=event_ticker,
        series_ticker=series_ticker,
        max_close_ts=max_close_ts,
        min_close_ts=min_close_ts,
        status=status,
        tickers=tickers,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
    series_ticker: Union[Unset, str] = UNSET,
    max_close_ts: Union[Unset, int] = UNSET,
    min_close_ts: Union[Unset, int] = UNSET,
    status: Union[Unset, str] = UNSET,
    tickers: Union[Unset, str] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse]:
    r"""Get Markets

      Endpoint for listing and discovering markets on Kalshi. A market represents a specific binary
    outcome within an event that users can trade on (e.g., \"Will candidate X win?\"). Markets have
    yes/no positions, current prices, volume, and settlement rules. This endpoint returns a paginated
    response. Use the 'limit' parameter to control page size (1-1000, defaults to 100). The response
    includes a 'cursor' field - pass this value in the 'cursor' parameter of your next request to get
    the next page. An empty cursor indicates no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        event_ticker (Union[Unset, str]): Filter markets by event ticker. Returns only markets
            belonging to the specified event.
        series_ticker (Union[Unset, str]): Filter markets by series ticker. Returns only markets
            belonging to events in the specified series.
        max_close_ts (Union[Unset, int]): Filter markets that close before this Unix timestamp.
        min_close_ts (Union[Unset, int]): Filter markets that close after this Unix timestamp.
        status (Union[Unset, str]): Filter by market status. Comma-separated list. Possible
            values: 'unopened', 'open', 'closed', 'settled'. Leave empty to return markets with any
            status.
        tickers (Union[Unset, str]): Filter by specific market tickers. Comma-separated list of
            market tickers to retrieve.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            limit=limit,
            cursor=cursor,
            event_ticker=event_ticker,
            series_ticker=series_ticker,
            max_close_ts=max_close_ts,
            min_close_ts=min_close_ts,
            status=status,
            tickers=tickers,
        )
    ).parsed



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_common_api_json_error import (
        GithubComKalshiExchangeInfraCommonApiJSONError,
    )
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_order import (
        GithubComKalshiExchangeInfraSvcApi2ModelOrder,
    )


T = TypeVar("T", bound="BatchCancelOrdersIndividualResponse")


@_attrs_define
class BatchCancelOrdersIndividualResponse:
    """
    Attributes:
        error (Union[Unset, GithubComKalshiExchangeInfraCommonApiJSONError]):
        order (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelOrder]):
        order_id (Union[Unset, str]):
        reduced_by (Union[Unset, int]): The number of contracts that were successfully canceled from this order.
    """

    error: Union[Unset, "GithubComKalshiExchangeInfraCommonApiJSONError"] = UNSET
    order: Union[Unset, "GithubComKalshiExchangeInfraSvcApi2ModelOrder"] = UNSET
    order_id: Union[Unset, str] = UNSET
    reduced_by: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        error: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        order: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.order, Unset):
            order = self.order.to_dict()

        order_id = self.order_id

        reduced_by = self.reduced_by

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if error is not UNSET:
            field_dict["error"] = error
        if order is not UNSET:
            field_dict["order"] = order
        if order_id is not UNSET:
            field_dict["order_id"] = order_id
        if reduced_by is not UNSET:
            field_dict["reduced_by"] = reduced_by

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_common_api_json_error import (
            GithubComKalshiExchangeInfraCommonApiJSONError,
        )
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_order import (
            GithubComKalshiExchangeInfraSvcApi2ModelOrder,
        )

        d = dict(src_dict)
        _error = d.pop("error", UNSET)
        error: Union[Unset, GithubComKalshiExchangeInfraCommonApiJSONError]
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = GithubComKalshiExchangeInfraCommonApiJSONError.from_dict(_error)

        _order = d.pop("order", UNSET)
        order: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelOrder]
        if isinstance(_order, Unset):
            order = UNSET
        else:
            order = GithubComKalshiExchangeInfraSvcApi2ModelOrder.from_dict(_order)

        order_id = d.pop("order_id", UNSET)

        reduced_by = d.pop("reduced_by", UNSET)

        batch_cancel_orders_individual_response = cls(
            error=error,
            order=order,
            order_id=order_id,
            reduced_by=reduced_by,
        )

        batch_cancel_orders_individual_response.additional_properties = d
        return batch_cancel_orders_individual_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Contains all the data models used in inputs/outputs"""

from .announcement import Announcement
from .api_key import ApiKey
from .batch_cancel_orders_individual_response import BatchCancelOrdersIndividualResponse
from .batch_create_orders_individual_response import BatchCreateOrdersIndividualResponse
from .daily_schedule import DailySchedule
from .event_position import EventPosition
from .generic_object import GenericObject
from .github_com_kalshi_exchange_infra_common_api_json_error import GithubComKalshiExchangeInfraCommonApiJSONError
from .github_com_kalshi_exchange_infra_common_communications_quote import (
    GithubComKalshiExchangeInfraCommonCommunicationsQuote,
)
from .github_com_kalshi_exchange_infra_common_communications_rfq import (
    GithubComKalshiExchangeInfraCommonCommunicationsRFQ,
)
from .github_com_kalshi_exchange_infra_common_exchange_metadata_daily_schedule import (
    GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule,
)
from .github_com_kalshi_exchange_infra_common_exchange_metadata_schedule import (
    GithubComKalshiExchangeInfraCommonExchangeMetadataSchedule,
)
from .github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_maintenance_windows_item import (
    GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem,
)
from .github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_standard_hours_item import (
    GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem,
)
from .github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_standard_hours_item_monday_item import (
    GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItemMondayItem,
)
from .github_com_kalshi_exchange_infra_common_unimodel_details import GithubComKalshiExchangeInfraCommonUnimodelDetails
from .github_com_kalshi_exchange_infra_common_unimodel_product_metadata import (
    GithubComKalshiExchangeInfraCommonUnimodelProductMetadata,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request_accepted_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_amend_order_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_amend_order_request_action import (
    GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequestAction,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_amend_order_request_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequestSide,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_amend_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_batch_cancel_orders_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelBatchCancelOrdersRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_batch_cancel_orders_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelBatchCancelOrdersResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_batch_cancel_orders_response_orders_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelBatchCancelOrdersResponseOrdersItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_batch_create_orders_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelBatchCreateOrdersRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_batch_create_orders_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelBatchCreateOrdersResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_batch_create_orders_response_orders_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelBatchCreateOrdersResponseOrdersItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_bid_ask_distribution import (
    GithubComKalshiExchangeInfraSvcApi2ModelBidAskDistribution,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_cancel_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_market_in_multivariate_event_collection_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_market_in_multivariate_event_collection_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_group_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderGroupRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_group_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderGroupResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_action import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_time_in_force import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_type import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_quote_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateQuoteRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_quote_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateQuoteResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_rfq_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateRFQRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_create_rfq_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateRFQResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_empty_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelEmptyResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_event_data import (
    GithubComKalshiExchangeInfraSvcApi2ModelEventData,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_exchange_status import (
    GithubComKalshiExchangeInfraSvcApi2ModelExchangeStatus,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_fill import GithubComKalshiExchangeInfraSvcApi2ModelFill
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_balance_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetBalanceResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_communications_id_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetCommunicationsIDResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_event_metadata_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetEventMetadataResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_event_metadata_response_settlement_sources_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetEventMetadataResponseSettlementSourcesItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_event_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_events_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetEventsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_exchange_announcements_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetExchangeAnnouncementsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_exchange_announcements_response_announcements_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetExchangeAnnouncementsResponseAnnouncementsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_exchange_schedule_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetExchangeScheduleResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_fills_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetFillsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_market_candlesticks_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_market_candlesticks_response_candlesticks_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponseCandlesticksItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_market_orderbook_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketOrderbookResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_market_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_markets_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_milestone_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMilestoneResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_milestones_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMilestonesResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response_lookup_points_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collections_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_order_group_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderGroupResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_order_groups_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderGroupsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_order_queue_position_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_order_queue_positions_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_order_queue_positions_response_queue_positions_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponseQueuePositionsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_orders_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrdersResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_positions_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetPositionsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_positions_response_event_positions_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetPositionsResponseEventPositionsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_positions_response_market_positions_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetPositionsResponseMarketPositionsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_quote_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetQuoteResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_quotes_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetQuotesResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_quotes_response_quotes_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetQuotesResponseQuotesItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response_rfqs_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_rfq_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetRFQResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response_settlements_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response_settlements_item_market_result import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_structured_target_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_structured_targets_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_user_data_timestamp_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_get_user_resting_order_total_value_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetUserRestingOrderTotalValueResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request_selected_markets_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request_selected_markets_item_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItemSide,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_market import GithubComKalshiExchangeInfraSvcApi2ModelMarket
from .github_com_kalshi_exchange_infra_svc_api_2_model_milestone import (
    GithubComKalshiExchangeInfraSvcApi2ModelMilestone,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection import (
    GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_order import GithubComKalshiExchangeInfraSvcApi2ModelOrder
from .github_com_kalshi_exchange_infra_svc_api_2_model_order_book import (
    GithubComKalshiExchangeInfraSvcApi2ModelOrderBook,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_order_book_no_dollars_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelOrderBookNoDollarsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_order_book_yes_dollars_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelOrderBookYesDollarsItem,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_order_confirmation import (
    GithubComKalshiExchangeInfraSvcApi2ModelOrderConfirmation,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_order_group_summary import (
    GithubComKalshiExchangeInfraSvcApi2ModelOrderGroupSummary,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_price_distribution import (
    GithubComKalshiExchangeInfraSvcApi2ModelPriceDistribution,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_public_trade import (
    GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_public_trades_get_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_structured_target import (
    GithubComKalshiExchangeInfraSvcApi2ModelStructuredTarget,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_ticker_pair import (
    GithubComKalshiExchangeInfraSvcApi2ModelTickerPair,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_ticker_pair_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelTickerPairSide,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_user_create_api_key_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_user_create_api_key_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_user_generate_api_key_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_user_generate_api_key_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_user_get_api_keys_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserGetApiKeysResponse,
)
from .github_com_kalshi_exchange_infra_svc_api_2_model_user_get_api_keys_response_api_keys_item import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserGetApiKeysResponseApiKeysItem,
)
from .lookup_point import LookupPoint
from .maintenance_window import MaintenanceWindow
from .market_candlestick import MarketCandlestick
from .market_position import MarketPosition
from .order_queue_position import OrderQueuePosition
from .price_level_dollars import PriceLevelDollars
from .settlement import Settlement
from .settlement_market_result import SettlementMarketResult
from .settlement_source import SettlementSource
from .ticker_pair import TickerPair
from .ticker_pair_side import TickerPairSide
from .weekly_schedule import WeeklySchedule
from .weekly_schedule_monday_item import WeeklyScheduleMondayItem

__all__ = (
    "Announcement",
    "ApiKey",
    "BatchCancelOrdersIndividualResponse",
    "BatchCreateOrdersIndividualResponse",
    "DailySchedule",
    "EventPosition",
    "GenericObject",
    "GithubComKalshiExchangeInfraCommonApiJSONError",
    "GithubComKalshiExchangeInfraCommonCommunicationsQuote",
    "GithubComKalshiExchangeInfraCommonCommunicationsRFQ",
    "GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule",
    "GithubComKalshiExchangeInfraCommonExchangeMetadataSchedule",
    "GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem",
    "GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem",
    "GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItemMondayItem",
    "GithubComKalshiExchangeInfraCommonUnimodelDetails",
    "GithubComKalshiExchangeInfraCommonUnimodelProductMetadata",
    "GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide",
    "GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequestAction",
    "GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequestSide",
    "GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelBatchCancelOrdersRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelBatchCancelOrdersResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelBatchCancelOrdersResponseOrdersItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelBatchCreateOrdersRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelBatchCreateOrdersResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelBatchCreateOrdersResponseOrdersItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelBidAskDistribution",
    "GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderGroupRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderGroupResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateQuoteRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateQuoteResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateRFQRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelCreateRFQResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelEmptyResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelEventData",
    "GithubComKalshiExchangeInfraSvcApi2ModelExchangeStatus",
    "GithubComKalshiExchangeInfraSvcApi2ModelFill",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetBalanceResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetCommunicationsIDResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetEventMetadataResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetEventMetadataResponseSettlementSourcesItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetEventsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetExchangeAnnouncementsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetExchangeAnnouncementsResponseAnnouncementsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetExchangeScheduleResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetFillsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponseCandlesticksItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMarketOrderbookResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMarketResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMarketsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMilestoneResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMilestonesResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrderGroupResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrderGroupsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponseQueuePositionsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrderResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetOrdersResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetPositionsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetPositionsResponseEventPositionsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetPositionsResponseMarketPositionsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetQuoteResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetQuotesResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetQuotesResponseQuotesItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetRFQResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelGetUserRestingOrderTotalValueResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItemSide",
    "GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelMarket",
    "GithubComKalshiExchangeInfraSvcApi2ModelMilestone",
    "GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection",
    "GithubComKalshiExchangeInfraSvcApi2ModelOrder",
    "GithubComKalshiExchangeInfraSvcApi2ModelOrderBook",
    "GithubComKalshiExchangeInfraSvcApi2ModelOrderBookNoDollarsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelOrderBookYesDollarsItem",
    "GithubComKalshiExchangeInfraSvcApi2ModelOrderConfirmation",
    "GithubComKalshiExchangeInfraSvcApi2ModelOrderGroupSummary",
    "GithubComKalshiExchangeInfraSvcApi2ModelPriceDistribution",
    "GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade",
    "GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelStructuredTarget",
    "GithubComKalshiExchangeInfraSvcApi2ModelTickerPair",
    "GithubComKalshiExchangeInfraSvcApi2ModelTickerPairSide",
    "GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest",
    "GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelUserGetApiKeysResponse",
    "GithubComKalshiExchangeInfraSvcApi2ModelUserGetApiKeysResponseApiKeysItem",
    "LookupPoint",
    "MaintenanceWindow",
    "MarketCandlestick",
    "MarketPosition",
    "OrderQueuePosition",
    "PriceLevelDollars",
    "Settlement",
    "SettlementMarketResult",
    "SettlementSource",
    "TickerPair",
    "TickerPairSide",
    "WeeklySchedule",
    "WeeklyScheduleMondayItem",
)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiKey")


@_attrs_define
class ApiKey:
    """
    Attributes:
        api_key_id (Union[Unset, str]): Unique identifier for the API key.
        created_ts (Union[Unset, datetime.datetime]): Timestamp when the API key was created.
        name (Union[Unset, str]): User-provided name for the API key.
    """

    api_key_id: Union[Unset, str] = UNSET
    created_ts: Union[Unset, datetime.datetime] = UNSET
    name: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        api_key_id = self.api_key_id

        created_ts: Union[Unset, str] = UNSET
        if not isinstance(self.created_ts, Unset):
            created_ts = self.created_ts.isoformat()

        name = self.name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if api_key_id is not UNSET:
            field_dict["api_key_id"] = api_key_id
        if created_ts is not UNSET:
            field_dict["created_ts"] = created_ts
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_key_id = d.pop("api_key_id", UNSET)

        _created_ts = d.pop("created_ts", UNSET)
        created_ts: Union[Unset, datetime.datetime]
        if isinstance(_created_ts, Unset):
            created_ts = UNSET
        else:
            created_ts = isoparse(_created_ts)

        name = d.pop("name", UNSET)

        api_key = cls(
            api_key_id=api_key_id,
            created_ts=created_ts,
            name=name,
        )

        api_key.additional_properties = d
        return api_key

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...types import Response


def _get_kwargs(
    series_ticker: str,
) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/series/{series_ticker}",
    }

    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    series_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[Any]:
    r"""Get Series

      Endpoint for getting data about a specific series by its ticker.  A series represents a template
    for recurring events that follow the same format and rules (e.g., \"Monthly Jobs Report\", \"Weekly
    Initial Jobless Claims\", \"Daily Weather in NYC\"). Series define the structure, settlement
    sources, and metadata that will be applied to each recurring event instance within that series.

    Args:
        series_ticker (str): Series ticker - unique identifier for the specific series

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        series_ticker=series_ticker,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    series_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[Any]:
    r"""Get Series

      Endpoint for getting data about a specific series by its ticker.  A series represents a template
    for recurring events that follow the same format and rules (e.g., \"Monthly Jobs Report\", \"Weekly
    Initial Jobless Claims\", \"Daily Weather in NYC\"). Series define the structure, settlement
    sources, and metadata that will be applied to each recurring event instance within that series.

    Args:
        series_ticker (str): Series ticker - unique identifier for the specific series

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        series_ticker=series_ticker,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request_selected_markets_item import (
        GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItem,
    )


T = TypeVar(
    "T", bound="GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequest"
)


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequest:
    """
    Attributes:
        selected_markets (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariat
            eEventCollectionRequestSelectedMarketsItem']]): List of selected markets that act as parameters to determine
            which market is produced.
    """

    selected_markets: Union[
        Unset,
        list[
            "GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItem"
        ],
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        selected_markets: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.selected_markets, Unset):
            selected_markets = []
            for selected_markets_item_data in self.selected_markets:
                selected_markets_item = selected_markets_item_data.to_dict()
                selected_markets.append(selected_markets_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if selected_markets is not UNSET:
            field_dict["selected_markets"] = selected_markets

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request_selected_markets_item import (
            GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItem,
        )

        d = dict(src_dict)
        selected_markets = []
        _selected_markets = d.pop("selected_markets", UNSET)
        for selected_markets_item_data in _selected_markets or []:
            selected_markets_item = GithubComKalshiExchangeInfraSvcApi2ModelLookupTickersForMarketInMultivariateEventCollectionRequestSelectedMarketsItem.from_dict(
                selected_markets_item_data
            )

            selected_markets.append(selected_markets_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request = cls(
            selected_markets=selected_markets,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_lookup_tickers_for_market_in_multivariate_event_collection_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""A client library for accessing Kalshi Trade API"""

import os

from .auth import KalshiAuthenticatedClient
from .client import AuthenticatedClient, Client

__all__ = (
    "AuthenticatedClient",
    "Client",
    "KalshiAuthenticatedClient",
    "create_client",
)


def create_client(
    base_url: str = "https://api.elections.kalshi.com/trade-api/v2",
    access_key_id: str | None = None,
    private_key_path: str | None = None,
    private_key_data: str | None = None,
    **kwargs
) -> KalshiAuthenticatedClient:
    """Create an authenticated Kalshi client with RSA-PSS signature authentication.

    Args:
        base_url: API base URL (defaults to elections API)
        access_key_id: Kalshi access key ID (from environment if not provided)
        private_key_path: Path to private key file (mutually exclusive with private_key_data)
        private_key_data: PEM-encoded private key string (mutually exclusive with private_key_path)
        **kwargs: Additional arguments passed to the client

    Returns:
        Authenticated client instance

    Example:
        ```python
        from kalshi_py import create_client

        # Using environment variables
        client = create_client()

        # Or with file path
        client = create_client(
            access_key_id="your-key-id",
            private_key_path="/path/to/private-key.pem"
        )

        # Or with PEM data
        client = create_client(
            access_key_id="your-key-id",
            private_key_data="-----BEGIN PRIVATE KEY-----\n..."
        )
        ```
    """
    # Get access key ID from parameters or environment
    final_access_key_id = access_key_id or os.getenv("KALSHI_API_KEY_ID")

    if not final_access_key_id:
        raise ValueError("access_key_id must be provided or set in KALSHI_API_KEY_ID environment variable")

    # Handle private key - check for mutual exclusivity
    if private_key_path and private_key_data:
        raise ValueError("Cannot specify both private_key_path and private_key_data")

    if private_key_path:
        # Read from file
        with open(private_key_path) as f:
            final_private_key_data = f.read()
    elif private_key_data:
        # Use provided PEM data
        final_private_key_data = private_key_data
    else:
        # Try environment variable
        final_private_key_data = os.getenv("KALSHI_PY_PRIVATE_KEY_PEM")

    if not final_private_key_data:
        raise ValueError("private_key_path, private_key_data, or KALSHI_PY_PRIVATE_KEY_PEM environment variable must be provided")

    return KalshiAuthenticatedClient(
        base_url=base_url,
        access_key_id=final_access_key_id,
        private_key_pem=final_private_key_data,
        **kwargs
    )



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_get_order_queue_positions_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    market_tickers: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["market_tickers"] = market_tickers

    params["event_ticker"] = event_ticker

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/portfolio/orders/queue_positions",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    market_tickers: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]:
    """Get Queue Positions for Orders

      Endpoint for getting queue positions for all resting orders. Queue position represents the number
    of contracts that need to be matched before an order receives a partial or full match, determined
    using price-time priority.

    Args:
        market_tickers (Union[Unset, str]): Comma-separated list of market tickers to filter by
        event_ticker (Union[Unset, str]): Event ticker to filter by

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]
    """

    kwargs = _get_kwargs(
        market_tickers=market_tickers,
        event_ticker=event_ticker,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    market_tickers: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]:
    """Get Queue Positions for Orders

      Endpoint for getting queue positions for all resting orders. Queue position represents the number
    of contracts that need to be matched before an order receives a partial or full match, determined
    using price-time priority.

    Args:
        market_tickers (Union[Unset, str]): Comma-separated list of market tickers to filter by
        event_ticker (Union[Unset, str]): Event ticker to filter by

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse
    """

    return sync_detailed(
        client=client,
        market_tickers=market_tickers,
        event_ticker=event_ticker,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    market_tickers: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]:
    """Get Queue Positions for Orders

      Endpoint for getting queue positions for all resting orders. Queue position represents the number
    of contracts that need to be matched before an order receives a partial or full match, determined
    using price-time priority.

    Args:
        market_tickers (Union[Unset, str]): Comma-separated list of market tickers to filter by
        event_ticker (Union[Unset, str]): Event ticker to filter by

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]
    """

    kwargs = _get_kwargs(
        market_tickers=market_tickers,
        event_ticker=event_ticker,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    market_tickers: Union[Unset, str] = UNSET,
    event_ticker: Union[Unset, str] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse]:
    """Get Queue Positions for Orders

      Endpoint for getting queue positions for all resting orders. Queue position represents the number
    of contracts that need to be matched before an order receives a partial or full match, determined
    using price-time priority.

    Args:
        market_tickers (Union[Unset, str]): Comma-separated list of market tickers to filter by
        event_ticker (Union[Unset, str]): Event ticker to filter by

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetOrderQueuePositionsResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            market_tickers=market_tickers,
            event_ticker=event_ticker,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelOrderBookNoDollarsItem")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelOrderBookNoDollarsItem:
    """
    Attributes:
        count (Union[Unset, int]):
        dollars (Union[Unset, list[int]]):
    """

    count: Union[Unset, int] = UNSET
    dollars: Union[Unset, list[int]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        count = self.count

        dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.dollars, Unset):
            dollars = self.dollars

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if count is not UNSET:
            field_dict["Count"] = count
        if dollars is not UNSET:
            field_dict["Dollars"] = dollars

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        count = d.pop("Count", UNSET)

        dollars = cast(list[int], d.pop("Dollars", UNSET))

        github_com_kalshi_exchange_infra_svc_api_2_model_order_book_no_dollars_item = cls(
            count=count,
            dollars=dollars,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_order_book_no_dollars_item.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_order_book_no_dollars_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_get_structured_targets_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    type_: Union[Unset, str] = UNSET,
    competition: Union[Unset, str] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["type"] = type_

    params["competition"] = competition

    params["page_size"] = page_size

    params["cursor"] = cursor

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/structured_targets",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    type_: Union[Unset, str] = UNSET,
    competition: Union[Unset, str] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]:
    """Get Structured Targets

      Endpoint for getting data about structured targets.

    Args:
        type_ (Union[Unset, str]): Type of structured target
        competition (Union[Unset, str]): Competition filter
        page_size (Union[Unset, int]): Page size (min: 1, max: 2000)
        cursor (Union[Unset, str]): Pagination cursor

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]
    """

    kwargs = _get_kwargs(
        type_=type_,
        competition=competition,
        page_size=page_size,
        cursor=cursor,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    type_: Union[Unset, str] = UNSET,
    competition: Union[Unset, str] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]:
    """Get Structured Targets

      Endpoint for getting data about structured targets.

    Args:
        type_ (Union[Unset, str]): Type of structured target
        competition (Union[Unset, str]): Competition filter
        page_size (Union[Unset, int]): Page size (min: 1, max: 2000)
        cursor (Union[Unset, str]): Pagination cursor

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse
    """

    return sync_detailed(
        client=client,
        type_=type_,
        competition=competition,
        page_size=page_size,
        cursor=cursor,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    type_: Union[Unset, str] = UNSET,
    competition: Union[Unset, str] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]:
    """Get Structured Targets

      Endpoint for getting data about structured targets.

    Args:
        type_ (Union[Unset, str]): Type of structured target
        competition (Union[Unset, str]): Competition filter
        page_size (Union[Unset, int]): Page size (min: 1, max: 2000)
        cursor (Union[Unset, str]): Pagination cursor

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]
    """

    kwargs = _get_kwargs(
        type_=type_,
        competition=competition,
        page_size=page_size,
        cursor=cursor,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    type_: Union[Unset, str] = UNSET,
    competition: Union[Unset, str] = UNSET,
    page_size: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse]:
    """Get Structured Targets

      Endpoint for getting data about structured targets.

    Args:
        type_ (Union[Unset, str]): Type of structured target
        competition (Union[Unset, str]): Competition filter
        page_size (Union[Unset, int]): Page size (min: 1, max: 2000)
        cursor (Union[Unset, str]): Pagination cursor

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetStructuredTargetsResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            type_=type_,
            competition=competition,
            page_size=page_size,
            cursor=cursor,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem:
    """
    Attributes:
        cancellation_reason (Union[Unset, str]): Reason for RFQ cancellation if cancelled.
        cancelled_ts (Union[Unset, datetime.datetime]): Timestamp when the RFQ was cancelled.
        contracts (Union[Unset, int]): Number of contracts requested in the RFQ.
        created_ts (Union[Unset, datetime.datetime]): Timestamp when the RFQ was created.
        creator_id (Union[Unset, str]):
        creator_user_id (Union[Unset, str]):
        id (Union[Unset, str]):
        market_ticker (Union[Unset, str]): The ticker of the market this RFQ is for.
        rest_remainder (Union[Unset, bool]): Whether to rest the remainder of the RFQ after execution.
        status (Union[Unset, str]):
        updated_ts (Union[Unset, datetime.datetime]): Timestamp when the RFQ was last updated.
    """

    cancellation_reason: Union[Unset, str] = UNSET
    cancelled_ts: Union[Unset, datetime.datetime] = UNSET
    contracts: Union[Unset, int] = UNSET
    created_ts: Union[Unset, datetime.datetime] = UNSET
    creator_id: Union[Unset, str] = UNSET
    creator_user_id: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    market_ticker: Union[Unset, str] = UNSET
    rest_remainder: Union[Unset, bool] = UNSET
    status: Union[Unset, str] = UNSET
    updated_ts: Union[Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        cancellation_reason = self.cancellation_reason

        cancelled_ts: Union[Unset, str] = UNSET
        if not isinstance(self.cancelled_ts, Unset):
            cancelled_ts = self.cancelled_ts.isoformat()

        contracts = self.contracts

        created_ts: Union[Unset, str] = UNSET
        if not isinstance(self.created_ts, Unset):
            created_ts = self.created_ts.isoformat()

        creator_id = self.creator_id

        creator_user_id = self.creator_user_id

        id = self.id

        market_ticker = self.market_ticker

        rest_remainder = self.rest_remainder

        status = self.status

        updated_ts: Union[Unset, str] = UNSET
        if not isinstance(self.updated_ts, Unset):
            updated_ts = self.updated_ts.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cancellation_reason is not UNSET:
            field_dict["cancellation_reason"] = cancellation_reason
        if cancelled_ts is not UNSET:
            field_dict["cancelled_ts"] = cancelled_ts
        if contracts is not UNSET:
            field_dict["contracts"] = contracts
        if created_ts is not UNSET:
            field_dict["created_ts"] = created_ts
        if creator_id is not UNSET:
            field_dict["creator_id"] = creator_id
        if creator_user_id is not UNSET:
            field_dict["creator_user_id"] = creator_user_id
        if id is not UNSET:
            field_dict["id"] = id
        if market_ticker is not UNSET:
            field_dict["market_ticker"] = market_ticker
        if rest_remainder is not UNSET:
            field_dict["rest_remainder"] = rest_remainder
        if status is not UNSET:
            field_dict["status"] = status
        if updated_ts is not UNSET:
            field_dict["updated_ts"] = updated_ts

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        cancellation_reason = d.pop("cancellation_reason", UNSET)

        _cancelled_ts = d.pop("cancelled_ts", UNSET)
        cancelled_ts: Union[Unset, datetime.datetime]
        if isinstance(_cancelled_ts, Unset):
            cancelled_ts = UNSET
        else:
            cancelled_ts = isoparse(_cancelled_ts)

        contracts = d.pop("contracts", UNSET)

        _created_ts = d.pop("created_ts", UNSET)
        created_ts: Union[Unset, datetime.datetime]
        if isinstance(_created_ts, Unset):
            created_ts = UNSET
        else:
            created_ts = isoparse(_created_ts)

        creator_id = d.pop("creator_id", UNSET)

        creator_user_id = d.pop("creator_user_id", UNSET)

        id = d.pop("id", UNSET)

        market_ticker = d.pop("market_ticker", UNSET)

        rest_remainder = d.pop("rest_remainder", UNSET)

        status = d.pop("status", UNSET)

        _updated_ts = d.pop("updated_ts", UNSET)
        updated_ts: Union[Unset, datetime.datetime]
        if isinstance(_updated_ts, Unset):
            updated_ts = UNSET
        else:
            updated_ts = isoparse(_updated_ts)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response_rfqs_item = cls(
            cancellation_reason=cancellation_reason,
            cancelled_ts=cancelled_ts,
            contracts=contracts,
            created_ts=created_ts,
            creator_id=creator_id,
            creator_user_id=creator_user_id,
            id=id,
            market_ticker=market_ticker,
            rest_remainder=rest_remainder,
            status=status,
            updated_ts=updated_ts,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response_rfqs_item.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response_rfqs_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_common_unimodel_details import (
        GithubComKalshiExchangeInfraCommonUnimodelDetails,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelStructuredTarget")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelStructuredTarget:
    """
    Attributes:
        details (Union[Unset, GithubComKalshiExchangeInfraCommonUnimodelDetails]):
        id (Union[Unset, str]): Unique identifier for the structured target.
        last_updated_ts (Union[Unset, datetime.datetime]): Timestamp when this structured target was last updated.
        name (Union[Unset, str]): Name of the structured target.
        source_id (Union[Unset, str]): External source identifier for the structured target, if available (e.g., third-
            party data provider ID).
        type_ (Union[Unset, str]): Type of the structured target.
    """

    details: Union[Unset, "GithubComKalshiExchangeInfraCommonUnimodelDetails"] = UNSET
    id: Union[Unset, str] = UNSET
    last_updated_ts: Union[Unset, datetime.datetime] = UNSET
    name: Union[Unset, str] = UNSET
    source_id: Union[Unset, str] = UNSET
    type_: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        details: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict()

        id = self.id

        last_updated_ts: Union[Unset, str] = UNSET
        if not isinstance(self.last_updated_ts, Unset):
            last_updated_ts = self.last_updated_ts.isoformat()

        name = self.name

        source_id = self.source_id

        type_ = self.type_

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if details is not UNSET:
            field_dict["details"] = details
        if id is not UNSET:
            field_dict["id"] = id
        if last_updated_ts is not UNSET:
            field_dict["last_updated_ts"] = last_updated_ts
        if name is not UNSET:
            field_dict["name"] = name
        if source_id is not UNSET:
            field_dict["source_id"] = source_id
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_common_unimodel_details import (
            GithubComKalshiExchangeInfraCommonUnimodelDetails,
        )

        d = dict(src_dict)
        _details = d.pop("details", UNSET)
        details: Union[Unset, GithubComKalshiExchangeInfraCommonUnimodelDetails]
        if isinstance(_details, Unset):
            details = UNSET
        else:
            details = GithubComKalshiExchangeInfraCommonUnimodelDetails.from_dict(_details)

        id = d.pop("id", UNSET)

        _last_updated_ts = d.pop("last_updated_ts", UNSET)
        last_updated_ts: Union[Unset, datetime.datetime]
        if isinstance(_last_updated_ts, Unset):
            last_updated_ts = UNSET
        else:
            last_updated_ts = isoparse(_last_updated_ts)

        name = d.pop("name", UNSET)

        source_id = d.pop("source_id", UNSET)

        type_ = d.pop("type", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_structured_target = cls(
            details=details,
            id=id,
            last_updated_ts=last_updated_ts,
            name=name,
            source_id=source_id,
            type_=type_,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_structured_target.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_structured_target

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_user_generate_api_key_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
)
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_user_generate_api_key_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse,
)
from ...types import Response


def _get_kwargs(
    *,
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api_keys/generate",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]:
    if response.status_code == 201:
        response_201 = GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse.from_dict(response.json())

        return response_201
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]:
    """Generate API Key

      Endpoint for generating a new API key with an automatically created key pair.  This endpoint
    generates both a public and private RSA key pair. The public key is stored on the platform, while
    the private key is returned to the user and must be stored securely. The private key cannot be
    retrieved again.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]:
    """Generate API Key

      Endpoint for generating a new API key with an automatically created key pair.  This endpoint
    generates both a public and private RSA key pair. The public key is stored on the platform, while
    the private key is returned to the user and must be stored securely. The private key cannot be
    retrieved again.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]:
    """Generate API Key

      Endpoint for generating a new API key with an automatically created key pair.  This endpoint
    generates both a public and private RSA key pair. The public key is stored on the platform, while
    the private key is returned to the user and must be stored securely. The private key cannot be
    retrieved again.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse]:
    """Generate API Key

      Endpoint for generating a new API key with an automatically created key pair.  This endpoint
    generates both a public and private RSA key pair. The public key is stored on the platform, while
    the private key is returned to the user and must be stored securely. The private key cannot be
    retrieved again.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelUserGenerateApiKeyResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response_lookup_points_item import (
        GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponse:
    """
    Attributes:
        lookup_points (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHi
            storyResponseLookupPointsItem']]): List of recent lookup points in the collection.
    """

    lookup_points: Union[
        Unset,
        list[
            "GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem"
        ],
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        lookup_points: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.lookup_points, Unset):
            lookup_points = []
            for lookup_points_item_data in self.lookup_points:
                lookup_points_item = lookup_points_item_data.to_dict()
                lookup_points.append(lookup_points_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if lookup_points is not UNSET:
            field_dict["lookup_points"] = lookup_points

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response_lookup_points_item import (
            GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem,
        )

        d = dict(src_dict)
        lookup_points = []
        _lookup_points = d.pop("lookup_points", UNSET)
        for lookup_points_item_data in _lookup_points or []:
            lookup_points_item = GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem.from_dict(
                lookup_points_item_data
            )

            lookup_points.append(lookup_points_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response = (
            cls(
                lookup_points=lookup_points,
            )
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response.additional_properties = d
        return (
            github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response
        )

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelOrderConfirmation")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelOrderConfirmation:
    """
    Attributes:
        action (Union[Unset, str]):
        client_order_id (Union[Unset, str]):
        created_time (Union[Unset, Any]):
        expiration_time (Union[Unset, Any]):
        no_price (Union[Unset, int]):
        no_price_dollars (Union[Unset, list[int]]):
        order_group_id (Union[Unset, str]):
        order_id (Union[Unset, str]): Unique identifier for orders.
        self_trade_prevention_type (Union[Unset, str]):
        side (Union[Unset, str]):
        status (Union[Unset, str]):
        ticker (Union[Unset, str]): Unique identifier for markets.
        type_ (Union[Unset, str]):
        user_id (Union[Unset, str]): Unique identifier for users.
        yes_price (Union[Unset, int]):
        yes_price_dollars (Union[Unset, list[int]]):
    """

    action: Union[Unset, str] = UNSET
    client_order_id: Union[Unset, str] = UNSET
    created_time: Union[Unset, Any] = UNSET
    expiration_time: Union[Unset, Any] = UNSET
    no_price: Union[Unset, int] = UNSET
    no_price_dollars: Union[Unset, list[int]] = UNSET
    order_group_id: Union[Unset, str] = UNSET
    order_id: Union[Unset, str] = UNSET
    self_trade_prevention_type: Union[Unset, str] = UNSET
    side: Union[Unset, str] = UNSET
    status: Union[Unset, str] = UNSET
    ticker: Union[Unset, str] = UNSET
    type_: Union[Unset, str] = UNSET
    user_id: Union[Unset, str] = UNSET
    yes_price: Union[Unset, int] = UNSET
    yes_price_dollars: Union[Unset, list[int]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        action = self.action

        client_order_id = self.client_order_id

        created_time = self.created_time

        expiration_time = self.expiration_time

        no_price = self.no_price

        no_price_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.no_price_dollars, Unset):
            no_price_dollars = self.no_price_dollars

        order_group_id = self.order_group_id

        order_id = self.order_id

        self_trade_prevention_type = self.self_trade_prevention_type

        side = self.side

        status = self.status

        ticker = self.ticker

        type_ = self.type_

        user_id = self.user_id

        yes_price = self.yes_price

        yes_price_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.yes_price_dollars, Unset):
            yes_price_dollars = self.yes_price_dollars

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if action is not UNSET:
            field_dict["action"] = action
        if client_order_id is not UNSET:
            field_dict["client_order_id"] = client_order_id
        if created_time is not UNSET:
            field_dict["created_time"] = created_time
        if expiration_time is not UNSET:
            field_dict["expiration_time"] = expiration_time
        if no_price is not UNSET:
            field_dict["no_price"] = no_price
        if no_price_dollars is not UNSET:
            field_dict["no_price_dollars"] = no_price_dollars
        if order_group_id is not UNSET:
            field_dict["order_group_id"] = order_group_id
        if order_id is not UNSET:
            field_dict["order_id"] = order_id
        if self_trade_prevention_type is not UNSET:
            field_dict["self_trade_prevention_type"] = self_trade_prevention_type
        if side is not UNSET:
            field_dict["side"] = side
        if status is not UNSET:
            field_dict["status"] = status
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if type_ is not UNSET:
            field_dict["type"] = type_
        if user_id is not UNSET:
            field_dict["user_id"] = user_id
        if yes_price is not UNSET:
            field_dict["yes_price"] = yes_price
        if yes_price_dollars is not UNSET:
            field_dict["yes_price_dollars"] = yes_price_dollars

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        action = d.pop("action", UNSET)

        client_order_id = d.pop("client_order_id", UNSET)

        created_time = d.pop("created_time", UNSET)

        expiration_time = d.pop("expiration_time", UNSET)

        no_price = d.pop("no_price", UNSET)

        no_price_dollars = cast(list[int], d.pop("no_price_dollars", UNSET))

        order_group_id = d.pop("order_group_id", UNSET)

        order_id = d.pop("order_id", UNSET)

        self_trade_prevention_type = d.pop("self_trade_prevention_type", UNSET)

        side = d.pop("side", UNSET)

        status = d.pop("status", UNSET)

        ticker = d.pop("ticker", UNSET)

        type_ = d.pop("type", UNSET)

        user_id = d.pop("user_id", UNSET)

        yes_price = d.pop("yes_price", UNSET)

        yes_price_dollars = cast(list[int], d.pop("yes_price_dollars", UNSET))

        github_com_kalshi_exchange_infra_svc_api_2_model_order_confirmation = cls(
            action=action,
            client_order_id=client_order_id,
            created_time=created_time,
            expiration_time=expiration_time,
            no_price=no_price,
            no_price_dollars=no_price_dollars,
            order_group_id=order_group_id,
            order_id=order_id,
            self_trade_prevention_type=self_trade_prevention_type,
            side=side,
            status=status,
            ticker=ticker,
            type_=type_,
            user_id=user_id,
            yes_price=yes_price,
            yes_price_dollars=yes_price_dollars,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_order_confirmation.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_order_confirmation

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraCommonApiJSONError")


@_attrs_define
class GithubComKalshiExchangeInfraCommonApiJSONError:
    """
    Attributes:
        code (Union[Unset, str]): A short identifier for the error type.
        details (Union[Unset, str]): Additional details about the error, if available.
        message (Union[Unset, str]): A human-readable description of the error.
        service (Union[Unset, str]): The name of the service that generated the error.
    """

    code: Union[Unset, str] = UNSET
    details: Union[Unset, str] = UNSET
    message: Union[Unset, str] = UNSET
    service: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        code = self.code

        details = self.details

        message = self.message

        service = self.service

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if code is not UNSET:
            field_dict["code"] = code
        if details is not UNSET:
            field_dict["details"] = details
        if message is not UNSET:
            field_dict["message"] = message
        if service is not UNSET:
            field_dict["service"] = service

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        code = d.pop("code", UNSET)

        details = d.pop("details", UNSET)

        message = d.pop("message", UNSET)

        service = d.pop("service", UNSET)

        github_com_kalshi_exchange_infra_common_api_json_error = cls(
            code=code,
            details=details,
            message=message,
            service=service,
        )

        github_com_kalshi_exchange_infra_common_api_json_error.additional_properties = d
        return github_com_kalshi_exchange_infra_common_api_json_error

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GithubComKalshiExchangeInfraSvcApi2ModelAmendOrderRequestAction(str, Enum):
    BUY = "buy"
    SELL = "sell"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest:
    """
    Attributes:
        reduce_by (Union[Unset, int]): Number of contracts to decrease the order's count by. One of reduce_by or
            reduce_to must be provided.
        reduce_to (Union[Unset, int]): Number of contracts to decrease the order to. If the orders remaining count is
            lower, it does nothing. One of reduce_by or reduce_to must be provided.
    """

    reduce_by: Union[Unset, int] = UNSET
    reduce_to: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        reduce_by = self.reduce_by

        reduce_to = self.reduce_to

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if reduce_by is not UNSET:
            field_dict["reduce_by"] = reduce_by
        if reduce_to is not UNSET:
            field_dict["reduce_to"] = reduce_to

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        reduce_by = d.pop("reduce_by", UNSET)

        reduce_to = d.pop("reduce_to", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_request = cls(
            reduce_by=reduce_by,
            reduce_to=reduce_to,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_request.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelExchangeStatus")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelExchangeStatus:
    """
    Attributes:
        exchange_active (Union[Unset, bool]): False if the core Kalshi exchange is no longer taking any state changes at
            all. This includes but is not limited to trading, new users, and transfers. True unless we are under
            maintenance.
        exchange_estimated_resume_time (Union[Unset, Any]):
        trading_active (Union[Unset, bool]): True if we are currently permitting trading on the exchange. This is true
            during trading hours and false outside exchange hours. Kalshi reserves the right to pause at any time in case
            issues are detected.
    """

    exchange_active: Union[Unset, bool] = UNSET
    exchange_estimated_resume_time: Union[Unset, Any] = UNSET
    trading_active: Union[Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        exchange_active = self.exchange_active

        exchange_estimated_resume_time = self.exchange_estimated_resume_time

        trading_active = self.trading_active

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if exchange_active is not UNSET:
            field_dict["exchange_active"] = exchange_active
        if exchange_estimated_resume_time is not UNSET:
            field_dict["exchange_estimated_resume_time"] = exchange_estimated_resume_time
        if trading_active is not UNSET:
            field_dict["trading_active"] = trading_active

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        exchange_active = d.pop("exchange_active", UNSET)

        exchange_estimated_resume_time = d.pop("exchange_estimated_resume_time", UNSET)

        trading_active = d.pop("trading_active", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_exchange_status = cls(
            exchange_active=exchange_active,
            exchange_estimated_resume_time=exchange_estimated_resume_time,
            trading_active=trading_active,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_exchange_status.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_exchange_status

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response_rfqs_item import (
        GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponse:
    """
    Attributes:
        cursor (Union[Unset, str]): Cursor for pagination to get the next page of results.
        rfqs (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem']]): List of RFQs
            matching the query criteria.
    """

    cursor: Union[Unset, str] = UNSET
    rfqs: Union[Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        cursor = self.cursor

        rfqs: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.rfqs, Unset):
            rfqs = []
            for rfqs_item_data in self.rfqs:
                rfqs_item = rfqs_item_data.to_dict()
                rfqs.append(rfqs_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if rfqs is not UNSET:
            field_dict["rfqs"] = rfqs

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response_rfqs_item import (
            GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem,
        )

        d = dict(src_dict)
        cursor = d.pop("cursor", UNSET)

        rfqs = []
        _rfqs = d.pop("rfqs", UNSET)
        for rfqs_item_data in _rfqs or []:
            rfqs_item = GithubComKalshiExchangeInfraSvcApi2ModelGetRFQsResponseRfqsItem.from_dict(rfqs_item_data)

            rfqs.append(rfqs_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response = cls(
            cursor=cursor,
            rfqs=rfqs,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_rf_qs_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_public_trades_get_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    ticker: Union[Unset, str] = UNSET,
    min_ts: Union[Unset, int] = UNSET,
    max_ts: Union[Unset, int] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["limit"] = limit

    params["cursor"] = cursor

    params["ticker"] = ticker

    params["min_ts"] = min_ts

    params["max_ts"] = max_ts

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/markets/trades",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    ticker: Union[Unset, str] = UNSET,
    min_ts: Union[Unset, int] = UNSET,
    max_ts: Union[Unset, int] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]:
    """Get Trades

      Endpoint for getting all trades for all markets.  A trade represents a completed transaction
    between two users on a specific market. Each trade includes the market ticker, price, quantity, and
    timestamp information.  This endpoint returns a paginated response. Use the 'limit' parameter to
    control page size (1-1000, defaults to 100). The response includes a 'cursor' field - pass this
    value in the 'cursor' parameter of your next request to get the next page. An empty cursor indicates
    no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        ticker (Union[Unset, str]): Filter trades by market ticker. Returns only trades for the
            specified market.
        min_ts (Union[Unset, int]): Filter trades that occurred after this Unix timestamp.
        max_ts (Union[Unset, int]): Filter trades that occurred before this Unix timestamp.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]
    """

    kwargs = _get_kwargs(
        limit=limit,
        cursor=cursor,
        ticker=ticker,
        min_ts=min_ts,
        max_ts=max_ts,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    ticker: Union[Unset, str] = UNSET,
    min_ts: Union[Unset, int] = UNSET,
    max_ts: Union[Unset, int] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]:
    """Get Trades

      Endpoint for getting all trades for all markets.  A trade represents a completed transaction
    between two users on a specific market. Each trade includes the market ticker, price, quantity, and
    timestamp information.  This endpoint returns a paginated response. Use the 'limit' parameter to
    control page size (1-1000, defaults to 100). The response includes a 'cursor' field - pass this
    value in the 'cursor' parameter of your next request to get the next page. An empty cursor indicates
    no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        ticker (Union[Unset, str]): Filter trades by market ticker. Returns only trades for the
            specified market.
        min_ts (Union[Unset, int]): Filter trades that occurred after this Unix timestamp.
        max_ts (Union[Unset, int]): Filter trades that occurred before this Unix timestamp.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse
    """

    return sync_detailed(
        client=client,
        limit=limit,
        cursor=cursor,
        ticker=ticker,
        min_ts=min_ts,
        max_ts=max_ts,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    ticker: Union[Unset, str] = UNSET,
    min_ts: Union[Unset, int] = UNSET,
    max_ts: Union[Unset, int] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]:
    """Get Trades

      Endpoint for getting all trades for all markets.  A trade represents a completed transaction
    between two users on a specific market. Each trade includes the market ticker, price, quantity, and
    timestamp information.  This endpoint returns a paginated response. Use the 'limit' parameter to
    control page size (1-1000, defaults to 100). The response includes a 'cursor' field - pass this
    value in the 'cursor' parameter of your next request to get the next page. An empty cursor indicates
    no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        ticker (Union[Unset, str]): Filter trades by market ticker. Returns only trades for the
            specified market.
        min_ts (Union[Unset, int]): Filter trades that occurred after this Unix timestamp.
        max_ts (Union[Unset, int]): Filter trades that occurred before this Unix timestamp.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]
    """

    kwargs = _get_kwargs(
        limit=limit,
        cursor=cursor,
        ticker=ticker,
        min_ts=min_ts,
        max_ts=max_ts,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    limit: Union[Unset, int] = UNSET,
    cursor: Union[Unset, str] = UNSET,
    ticker: Union[Unset, str] = UNSET,
    min_ts: Union[Unset, int] = UNSET,
    max_ts: Union[Unset, int] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse]:
    """Get Trades

      Endpoint for getting all trades for all markets.  A trade represents a completed transaction
    between two users on a specific market. Each trade includes the market ticker, price, quantity, and
    timestamp information.  This endpoint returns a paginated response. Use the 'limit' parameter to
    control page size (1-1000, defaults to 100). The response includes a 'cursor' field - pass this
    value in the 'cursor' parameter of your next request to get the next page. An empty cursor indicates
    no more pages are available.

    Args:
        limit (Union[Unset, int]): Number of results per page. Defaults to 100. Maximum value is
            1000.
        cursor (Union[Unset, str]): Pagination cursor. Use the cursor value returned from the
            previous response to get the next page of results. Leave empty for the first page.
        ticker (Union[Unset, str]): Filter trades by market ticker. Returns only trades for the
            specified market.
        min_ts (Union[Unset, int]): Filter trades that occurred after this Unix timestamp.
        max_ts (Union[Unset, int]): Filter trades that occurred before this Unix timestamp.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            limit=limit,
            cursor=cursor,
            ticker=ticker,
            min_ts=min_ts,
            max_ts=max_ts,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_ticker_pair import (
        GithubComKalshiExchangeInfraSvcApi2ModelTickerPair,
    )


T = TypeVar(
    "T",
    bound="GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem",
)


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionLookupHistoryResponseLookupPointsItem:
    """
    Attributes:
        event_ticker (Union[Unset, str]): Event ticker for the lookup point.
        last_queried_ts (Union[Unset, datetime.datetime]): Timestamp when this lookup was last queried.
        market_ticker (Union[Unset, str]): Market ticker for the lookup point.
        selected_markets (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelTickerPair']]): Markets that were
            selected for this lookup.
    """

    event_ticker: Union[Unset, str] = UNSET
    last_queried_ts: Union[Unset, datetime.datetime] = UNSET
    market_ticker: Union[Unset, str] = UNSET
    selected_markets: Union[Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelTickerPair"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        event_ticker = self.event_ticker

        last_queried_ts: Union[Unset, str] = UNSET
        if not isinstance(self.last_queried_ts, Unset):
            last_queried_ts = self.last_queried_ts.isoformat()

        market_ticker = self.market_ticker

        selected_markets: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.selected_markets, Unset):
            selected_markets = []
            for selected_markets_item_data in self.selected_markets:
                selected_markets_item = selected_markets_item_data.to_dict()
                selected_markets.append(selected_markets_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if event_ticker is not UNSET:
            field_dict["event_ticker"] = event_ticker
        if last_queried_ts is not UNSET:
            field_dict["last_queried_ts"] = last_queried_ts
        if market_ticker is not UNSET:
            field_dict["market_ticker"] = market_ticker
        if selected_markets is not UNSET:
            field_dict["selected_markets"] = selected_markets

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_ticker_pair import (
            GithubComKalshiExchangeInfraSvcApi2ModelTickerPair,
        )

        d = dict(src_dict)
        event_ticker = d.pop("event_ticker", UNSET)

        _last_queried_ts = d.pop("last_queried_ts", UNSET)
        last_queried_ts: Union[Unset, datetime.datetime]
        if isinstance(_last_queried_ts, Unset):
            last_queried_ts = UNSET
        else:
            last_queried_ts = isoparse(_last_queried_ts)

        market_ticker = d.pop("market_ticker", UNSET)

        selected_markets = []
        _selected_markets = d.pop("selected_markets", UNSET)
        for selected_markets_item_data in _selected_markets or []:
            selected_markets_item = GithubComKalshiExchangeInfraSvcApi2ModelTickerPair.from_dict(
                selected_markets_item_data
            )

            selected_markets.append(selected_markets_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response_lookup_points_item = cls(
            event_ticker=event_ticker,
            last_queried_ts=last_queried_ts,
            market_ticker=market_ticker,
            selected_markets=selected_markets,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response_lookup_points_item.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_lookup_history_response_lookup_points_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_order import (
        GithubComKalshiExchangeInfraSvcApi2ModelOrder,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetOrderResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetOrderResponse:
    """
    Attributes:
        order (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelOrder]):
    """

    order: Union[Unset, "GithubComKalshiExchangeInfraSvcApi2ModelOrder"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        order: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.order, Unset):
            order = self.order.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if order is not UNSET:
            field_dict["order"] = order

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_order import (
            GithubComKalshiExchangeInfraSvcApi2ModelOrder,
        )

        d = dict(src_dict)
        _order = d.pop("order", UNSET)
        order: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelOrder]
        if isinstance(_order, Unset):
            order = UNSET
        else:
            order = GithubComKalshiExchangeInfraSvcApi2ModelOrder.from_dict(_order)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_order_response = cls(
            order=order,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_order_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_order_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
